##  INTEGRATION_RUN_FINISHED (Integration API)

```
{
  "type": "INTEGRATION-API",
  "scope": "PARTIAL",
  "version": "1.0.0",
  "duration": 3.924405624,
  "progress": "FINISHED",
  "direction": "INBOUND",
  "errorCount": 0,
  "connectorId": "inbound-document-connector",
  "warningCount": 0,
  "connectorType": "inboundDocument",
  "integratedTool": "",
  "processedCount": 2,
  "synchronizationId": "865b71a1-e66f-49c0-89de-5bc5fb42401b"
}
```



